# lx-dtypes Documentation

Welcome to the developer and maintainer documentation for `lx-dtypes`. These pages
cover data modeling conventions, implementation details, and automation workflows
used throughout the project.

## Contents
```{toctree}
:maxdepth: 2
:caption: API Reference

api/index
```

```{toctree}
:maxdepth: 2
:caption: Guides

guides/pydantic-cheatsheet
guides/dates-and-times
```

## Quick Links
- Project repository: https://github.com/wg-lux/lx-data-models
- Issue tracker: https://github.com/wg-lux/lx-data-models/issues
- Python Package Index (coming soon)

Need another topic? Open a discussion or file an issue and we will expand the docs.
